package com.example.pdflib_demo;

import android.content.Context;
import android.support.v7.app.AppCompatActivity;
import com.pdflib.PDFlibException;
import com.pdflib.pdflib;

import java.io.File;
import java.io.InputStream;
import java.io.IOException;


public class starter_basic extends AppCompatActivity {
    private static void add_asset_to_pvf(Context context, pdflib p, String filename)
            throws IOException, PDFlibException {
        InputStream stream = context.getAssets().open(filename);
        byte[] imageData = new byte[stream.available()];
        stream.read(imageData);
        stream.close();
        p.create_pvf(filename, imageData, "");
    }

    public static String create_pdf(Context context) {
        String out;
        File data_dir = context.getFilesDir();
        final String absolute_path = data_dir.getAbsolutePath();
        final String outfile = absolute_path + "/starter_basic.pdf";

        pdflib p = null;
        String imagefile = "nesrin.jpg";
        String optlist;
        int image;

        try {
            p = new pdflib();

            /*
             * logging can be enabled like this:
             */
            p.set_option("logging={filename="+absolute_path+"/trace.txt remove classes {api=1}}");

            /*
             * This means we must check return values of load_font() etc.
             */
            p.set_option("errorpolicy=return");

            /*
             * fonts and images etc. are stored as assets
             * to use these resources we load them to
             * the PDFlib Virtual File System (PVF).
             */
            add_asset_to_pvf(context, p, imagefile);
            add_asset_to_pvf(context, p, "NotoSerif-Regular.ttf");

            if (p.begin_document(outfile, "") == -1)
                throw new Exception("Error: " + p.get_errmsg());

            p.set_info("Creator", "PDFlib starter sample");
            p.set_info("Title", "starter_basic");

            /*
             * We load the image before the first page, and use it on all pages
             */
            image = p.load_image("auto", imagefile, "");

            if (image == -1)
                throw new Exception("Error: " + p.get_errmsg());

            /* Page 1 */
            p.begin_page_ext(0,0, "width=a4.width height=a4.height");

            /* use NotoSerif-Regular font and unicode encoding for placing the text
             * and demonstrate various options how to pass the unicode text to PDFlib
             */
            optlist = "fontname={NotoSerif-Regular} encoding=unicode embedding fontsize=24 ";

            /* using plain 7 bit ASCII text */
            p.fit_textline("en: Hello!", 50, 700, optlist);
            /* using unicode escapes */
            p.fit_textline("gr: \u0393\u03B5\u03B9\u03AC!", 50, 650, optlist);
            p.fit_textline("ru: \u041F\u0440\u0438\u0432\u0435\u0442!", 50, 600, optlist);
            /* using PDFlib's character references */
            p.fit_textline("es: &#xA1;Hola!", 50, 550, optlist + " charref=true");

            p.fit_image(image, 0.0, 0.0, "scale=0.25");


            p.end_page_ext("");

            /* Page 2 */
            p.begin_page_ext(0,0, "width=a4.width height=a4.height");

            /* red rectangle */
            p.setcolor("fill", "rgb", 1.0, 0.0, 0.0, 0.0);
            p.rect(200, 200, 250, 150);
            p.fill();

            /* blue circle */
            p.setcolor("fill", "rgb", 0.0, 0.0, 1.0, 0.0);
            p.arc(400, 600, 100, 0, 360);
            p.fill();

            /* thick gray line */
            p.setcolor("stroke", "gray", 0.5, 0.0, 0.0, 0.0);
            p.setlinewidth(10);
            p.moveto(100, 500);
            p.lineto(300, 700);
            p.stroke();

            /*
             * Using the same image handle means the data will be copied to the
             * PDF only once, which saves space.
             */
            p.fit_image(image, 150.0, 25.0, "scale=0.25");
            p.end_page_ext("");

            /* Page 3 */
            p.begin_page_ext(0,0, "width=a4.width height=a4.height");

            /* Fit the image to a box of predefined size (without distortion) */
            optlist = "boxsize={400 400} position={center} fitmethod=meet";

            p.fit_image(image, 100, 200, optlist);

            p.end_page_ext("");

            p.close_image(image);
            p.end_document("");

            out = outfile + " created";

        }
        catch (PDFlibException e) {
            out = "PDFlib exception" + "[" + e.get_errnum() + "] "
                    + e.get_apiname() + ": " + e.get_errmsg() + "\n";
        }
        catch (Exception e) {
            out = "Exception: " + e.getMessage();
        }
        finally {
            if (p != null) {
                p.delete();
            }
        }

        return out;
    }
}